@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11861 2020-01-14 12:00:19Z Lavender $
+# $Id: __init__.py 11877 2020-01-19 07:42:51Z Trista $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2020-01-14 21:00:19 +0900 (週二, 14 一月 2020) $
-# $Revision: 11861 $
+# $Author: Trista $ (last)
+# $Date: 2020-01-19 15:42:51 +0800 (週日, 19 一月 2020) $
+# $Revision: 11877 $
 
 import os
 import sys
@@ -102,6 +102,7 @@ def attachSettings(settingsDict):
         'robots',
         'django_gravatar',
         'captcha',
+        'Zephyrus.map',
     ]
     
     if DJANGO_VERSION <= 20000: # 2.0.0
