@@ -1,7 +1,7 @@
 #!/bin/bash
 
-conda create -p Env%1 python=3.7 -y
-source activate Env%1
+conda create -p Env$1 python=3.7 -y
+source activate Env$1
 
 pip install -r REQUIREMENTS_$1.txt
 pip install -U django-cms==$1
