@@ -17,10 +17,16 @@
 
 from django.conf import settings
 from django.contrib.sitemaps import Sitemap
-from django.core.urlresolvers import reverse
 from django.utils.translation import get_language, activate
 from django.utils import translation
 
+from Iuppiter.DjangoUtil import DJANGO_VERSION
+
+if DJANGO_VERSION <= 20000: # 2.0.0:
+    from django.core.urlresolvers import reverse
+else:
+    from django.urls import reverse
+
 
 sitemaps = {}
 
